package javax.xml.datatype;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.URL;
import java.util.Properties;

final class FactoryFinder {
  private static final String CLASS_NAME = "javax.xml.datatype.FactoryFinder";
  
  private static boolean debug = false;
  
  private static Properties cacheProps = new Properties();
  
  private static boolean firstTime = true;
  
  private static final int DEFAULT_LINE_LENGTH = 80;
  
  private static void debugPrintln(String paramString) {
    if (debug)
      System.err.println("javax.xml.datatype.FactoryFinder:" + paramString); 
  }
  
  private static ClassLoader findClassLoader() throws ConfigurationError {
    ClassLoader classLoader = SecuritySupport.getContextClassLoader();
    if (debug)
      debugPrintln("Using context class loader: " + classLoader); 
    if (classLoader == null) {
      classLoader = FactoryFinder.class.getClassLoader();
      if (debug)
        debugPrintln("Using the class loader of FactoryFinder: " + classLoader); 
    } 
    return classLoader;
  }
  
  private static Object newInstance(String paramString, ClassLoader paramClassLoader) throws ConfigurationError {
    try {
      Class clazz;
      if (paramClassLoader == null) {
        clazz = Class.forName(paramString);
      } else {
        clazz = paramClassLoader.loadClass(paramString);
      } 
      if (debug)
        debugPrintln("Loaded " + paramString + " from " + which(clazz)); 
      return clazz.newInstance();
    } catch (ClassNotFoundException classNotFoundException) {
      throw new ConfigurationError("Provider " + paramString + " not found", classNotFoundException);
    } catch (Exception exception) {
      throw new ConfigurationError("Provider " + paramString + " could not be instantiated: " + exception, exception);
    } 
  }
  
  static Object find(String paramString1, String paramString2) throws ConfigurationError {
    ClassLoader classLoader = findClassLoader();
    try {
      String str = SecuritySupport.getSystemProperty(paramString1);
      if (str != null) {
        if (debug)
          debugPrintln("found " + str + " in the system property " + paramString1); 
        return newInstance(str, classLoader);
      } 
    } catch (SecurityException securityException) {}
    try {
      String str1 = SecuritySupport.getSystemProperty("java.home");
      String str2 = str1 + File.separator + "lib" + File.separator + "jaxp.properties";
      String str3 = null;
      if (firstTime)
        synchronized (cacheProps) {
          if (firstTime) {
            File file = new File(str2);
            firstTime = false;
            if (SecuritySupport.doesFileExist(file)) {
              if (debug)
                debugPrintln("Read properties file " + file); 
              cacheProps.load(SecuritySupport.getFileInputStream(file));
            } 
          } 
        }  
      str3 = cacheProps.getProperty(paramString1);
      if (debug)
        debugPrintln("found " + str3 + " in $java.home/jaxp.properties"); 
      if (str3 != null)
        return newInstance(str3, classLoader); 
    } catch (Exception exception) {
      if (debug)
        exception.printStackTrace(); 
    } 
    Object object = findJarServiceProvider(paramString1);
    if (object != null)
      return object; 
    if (paramString2 == null)
      throw new ConfigurationError("Provider for " + paramString1 + " cannot be found", null); 
    if (debug)
      debugPrintln("loaded from fallback value: " + paramString2); 
    return newInstance(paramString2, classLoader);
  }
  
  private static Object findJarServiceProvider(String paramString) throws ConfigurationError {
    String str1 = "META-INF/services/" + paramString;
    InputStream inputStream = null;
    ClassLoader classLoader = SecuritySupport.getContextClassLoader();
    if (classLoader != null) {
      inputStream = SecuritySupport.getResourceAsStream(classLoader, str1);
      if (inputStream == null) {
        classLoader = FactoryFinder.class.getClassLoader();
        inputStream = SecuritySupport.getResourceAsStream(classLoader, str1);
      } 
    } else {
      classLoader = FactoryFinder.class.getClassLoader();
      inputStream = SecuritySupport.getResourceAsStream(classLoader, str1);
    } 
    if (inputStream == null)
      return null; 
    if (debug)
      debugPrintln("found jar resource=" + str1 + " using ClassLoader: " + classLoader); 
    try {
      bufferedReader = new BufferedReader(new InputStreamReader(inputStream, "UTF-8"), 80);
    } catch (UnsupportedEncodingException unsupportedEncodingException) {
      bufferedReader = new BufferedReader(new InputStreamReader(inputStream), 80);
    } 
    String str2 = null;
    try {
      str2 = bufferedReader.readLine();
    } catch (IOException iOException) {
      return null;
    } finally {
      try {
        bufferedReader.close();
      } catch (IOException iOException) {}
    } 
    if (str2 != null && !"".equals(str2)) {
      if (debug)
        debugPrintln("found in resource, value=" + str2); 
      return newInstance(str2, classLoader);
    } 
    return null;
  }
  
  private static String which(Class paramClass) {
    try {
      URL uRL;
      String str = paramClass.getName().replace('.', '/') + ".class";
      ClassLoader classLoader = paramClass.getClassLoader();
      if (classLoader != null) {
        uRL = classLoader.getResource(str);
      } else {
        uRL = ClassLoader.getSystemResource(str);
      } 
      if (uRL != null)
        return uRL.toString(); 
    } catch (Throwable throwable) {
      if (debug)
        throwable.printStackTrace(); 
    } 
    return "unknown location";
  }
  
  static  {
    try {
      String str = SecuritySupport.getSystemProperty("jaxp.debug");
      debug = (str != null && !"false".equals(str));
    } catch (Exception exception) {
      debug = false;
    } 
  }
  
  static class ConfigurationError extends Error {
    private static final long serialVersionUID = -3644413026244211347L;
    
    private Exception exception;
    
    ConfigurationError(String param1String, Exception param1Exception) {
      super(param1String);
      this.exception = param1Exception;
    }
    
    Exception getException() { return this.exception; }
  }
}


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\xml-apis.jar!\javax\xml\datatype\FactoryFinder.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       1.0.7
 */