package javax.xml.xpath;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.NoSuchElementException;
import java.util.Properties;

final class XPathFactoryFinder {
  private static boolean debug = false;
  
  private static final int DEFAULT_LINE_LENGTH = 80;
  
  private static Properties cacheProps;
  
  private static boolean firstTime;
  
  private final ClassLoader classLoader;
  
  private static final Class SERVICE_CLASS;
  
  private static final String SERVICE_ID;
  
  private static void debugPrintln(String paramString) {
    if (debug)
      System.err.println("JAXP: " + paramString); 
  }
  
  public XPathFactoryFinder(ClassLoader paramClassLoader) {
    this.classLoader = paramClassLoader;
    if (debug)
      debugDisplayClassLoader(); 
  }
  
  private void debugDisplayClassLoader() {
    try {
      if (this.classLoader == SecuritySupport.getContextClassLoader()) {
        debugPrintln("using thread context class loader (" + this.classLoader + ") for search");
        return;
      } 
    } catch (Throwable throwable) {}
    if (this.classLoader == ClassLoader.getSystemClassLoader()) {
      debugPrintln("using system class loader (" + this.classLoader + ") for search");
      return;
    } 
    debugPrintln("using class loader (" + this.classLoader + ") for search");
  }
  
  public XPathFactory newFactory(String paramString) {
    if (paramString == null)
      throw new NullPointerException(); 
    XPathFactory xPathFactory = _newFactory(paramString);
    if (debug)
      if (xPathFactory != null) {
        debugPrintln("factory '" + xPathFactory.getClass().getName() + "' was found for " + paramString);
      } else {
        debugPrintln("unable to find a factory for " + paramString);
      }  
    return xPathFactory;
  }
  
  private XPathFactory _newFactory(String paramString) {
    String str1 = SERVICE_CLASS.getName() + ":" + paramString;
    try {
      if (debug)
        debugPrintln("Looking up system property '" + str1 + "'"); 
      String str = SecuritySupport.getSystemProperty(str1);
      if (str != null) {
        if (debug)
          debugPrintln("The value is '" + str + "'"); 
        XPathFactory xPathFactory = createInstance(str);
        if (xPathFactory != null)
          return xPathFactory; 
      } else if (debug) {
        debugPrintln("The property is undefined.");
      } 
    } catch (Throwable throwable) {
      if (debug) {
        debugPrintln("failed to look up system property '" + str1 + "'");
        throwable.printStackTrace();
      } 
    } 
    String str2 = SecuritySupport.getSystemProperty("java.home");
    String str3 = str2 + File.separator + "lib" + File.separator + "jaxp.properties";
    String str4 = null;
    try {
      if (firstTime)
        synchronized (cacheProps) {
          if (firstTime) {
            File file = new File(str3);
            firstTime = false;
            if (SecuritySupport.doesFileExist(file)) {
              if (debug)
                debugPrintln("Read properties file " + file); 
              cacheProps.load(SecuritySupport.getFileInputStream(file));
            } 
          } 
        }  
      str4 = cacheProps.getProperty(str1);
      if (debug)
        debugPrintln("found " + str4 + " in $java.home/jaxp.properties"); 
      if (str4 != null) {
        XPathFactory xPathFactory = createInstance(str4);
        if (xPathFactory != null)
          return xPathFactory; 
      } 
    } catch (Exception exception) {
      if (debug)
        exception.printStackTrace(); 
    } 
    Iterator iterator = createServiceFileIterator();
    while (iterator.hasNext()) {
      URL uRL = (URL)iterator.next();
      if (debug)
        debugPrintln("looking into " + uRL); 
      try {
        XPathFactory xPathFactory = loadFromServicesFile(paramString, uRL.toExternalForm(), SecuritySupport.getURLInputStream(uRL));
        if (xPathFactory != null)
          return xPathFactory; 
      } catch (IOException iOException) {
        if (debug) {
          debugPrintln("failed to read " + uRL);
          iOException.printStackTrace();
        } 
      } 
    } 
    if (paramString.equals("http://java.sun.com/jaxp/xpath/dom")) {
      if (debug)
        debugPrintln("attempting to use the platform default W3C DOM XPath lib"); 
      return createInstance("org.apache.xpath.jaxp.XPathFactoryImpl");
    } 
    if (debug)
      debugPrintln("all things were tried, but none was found. bailing out."); 
    return null;
  }
  
  private XPathFactory createInstance(String paramString) {
    try {
      Class clazz;
      if (debug)
        debugPrintln("instanciating " + paramString); 
      if (this.classLoader != null) {
        clazz = this.classLoader.loadClass(paramString);
      } else {
        clazz = Class.forName(paramString);
      } 
      if (debug)
        debugPrintln("loaded it from " + which(clazz)); 
      Object object = clazz.newInstance();
      if (object instanceof XPathFactory)
        return (XPathFactory)object; 
      if (debug)
        debugPrintln(paramString + " is not assignable to " + SERVICE_CLASS.getName()); 
    } catch (Throwable throwable) {
      if (debug) {
        debugPrintln("failed to instanciate " + paramString);
        throwable.printStackTrace();
      } 
    } 
    return null;
  }
  
  private XPathFactory loadFromServicesFile(String paramString1, String paramString2, InputStream paramInputStream) {
    BufferedReader bufferedReader;
    if (debug)
      debugPrintln("Reading " + paramString2); 
    try {
      bufferedReader = new BufferedReader(new InputStreamReader(paramInputStream, "UTF-8"), 80);
    } catch (UnsupportedEncodingException unsupportedEncodingException) {
      bufferedReader = new BufferedReader(new InputStreamReader(paramInputStream), 80);
    } 
    String str = null;
    XPathFactory xPathFactory = null;
    while (true) {
      try {
        str = bufferedReader.readLine();
      } catch (IOException iOException) {
        break;
      } 
      if (str != null) {
        int i = str.indexOf('#');
        if (i != -1)
          str = str.substring(0, i); 
        str = str.trim();
        if (str.length() == 0)
          continue; 
        try {
          XPathFactory xPathFactory1 = createInstance(str);
          if (xPathFactory1.isObjectModelSupported(paramString1)) {
            xPathFactory = xPathFactory1;
            break;
          } 
          continue;
        } catch (Exception exception) {
          continue;
        } 
      } 
      break;
    } 
    try {
      bufferedReader.close();
    } catch (IOException iOException) {}
    return xPathFactory;
  }
  
  private Iterator createServiceFileIterator() {
    if (this.classLoader == null)
      return new SingleIterator() {
          protected Object value() {
            ClassLoader classLoader = XPathFactoryFinder.class.getClassLoader();
            return SecuritySupport.getResourceAsURL(classLoader, SERVICE_ID);
          }
        }; 
    try {
      final Enumeration e = SecuritySupport.getResources(this.classLoader, SERVICE_ID);
      if (debug && !enumeration.hasMoreElements())
        debugPrintln("no " + SERVICE_ID + " file was found"); 
      return new Iterator() {
          public void remove() { throw new UnsupportedOperationException(); }
          
          public boolean hasNext() { return e.hasMoreElements(); }
          
          public Object next() { return e.nextElement(); }
        };
    } catch (IOException iOException) {
      if (debug) {
        debugPrintln("failed to enumerate resources " + SERVICE_ID);
        iOException.printStackTrace();
      } 
      return (new ArrayList()).iterator();
    } 
  }
  
  private static String which(Class paramClass) { return which(paramClass.getName(), paramClass.getClassLoader()); }
  
  private static String which(String paramString, ClassLoader paramClassLoader) {
    String str = paramString.replace('.', '/') + ".class";
    if (paramClassLoader == null)
      paramClassLoader = ClassLoader.getSystemClassLoader(); 
    URL uRL = SecuritySupport.getResourceAsURL(paramClassLoader, str);
    return (uRL != null) ? uRL.toString() : null;
  }
  
  static  {
    try {
      String str = SecuritySupport.getSystemProperty("jaxp.debug");
      debug = (str != null && !"false".equals(str));
    } catch (Exception exception) {
      debug = false;
    } 
    cacheProps = new Properties();
    firstTime = true;
    SERVICE_CLASS = XPathFactory.class;
    SERVICE_ID = "META-INF/services/" + SERVICE_CLASS.getName();
  }
  
  private static abstract class SingleIterator implements Iterator {
    private boolean seen = false;
    
    private SingleIterator() {}
    
    public final void remove() { throw new UnsupportedOperationException(); }
    
    public final boolean hasNext() { return !this.seen; }
    
    public final Object next() {
      if (this.seen)
        throw new NoSuchElementException(); 
      this.seen = true;
      return value();
    }
    
    protected abstract Object value();
  }
}


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\xml-apis.jar!\javax\xml\xpath\XPathFactoryFinder.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       1.0.7
 */